betty.string module - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.string module

Provide string handling utilities.

betty.string.camel_case_to_kebab_case(string: str) → str

  Convert camel case to kebab case.

  Parameters:

    string (`str`)

  Return type:

    `str`

betty.string.camel_case_to_snake_case(string: str) → str

  Convert camel case to snake case.

  Parameters:

    string (`str`)

  Return type:

    `str`

betty.string.snake_case_to_upper_camel_case(string: str) → str

  Convert snake case to upper camel case.

  Parameters:

    string (`str`)

  Return type:

    `str`

betty.string.upper_camel_case_to_lower_camel_case(string: str) → str

  Convert upper camel case to lower camel case.

  Parameters:

    string (`str`)

  Return type:

    `str`